<?php
// Auto-rebuild the theme registry during theme development.
if (theme_get_setting('rebuild_registry') && !defined('MAINTENANCE_MODE')) {
  // Rebuild .info data.
  system_rebuild_theme_data();
  // Rebuild theme registry.
  drupal_theme_rebuild();
}


/**
 * Maintenance page preprocessing
 */
function abc_preprocess_maintenance_page(&$vars) {
  if (class_exists('Database', FALSE)) {
    abc_preprocess_html($vars);  // set html vars (html.tpl.php is in maintenance-page.tpl.php)
    abc_preprocess_page($vars);  // set page vars
  }
}


/**
 * HTML preprocessing
 */
function abc_preprocess_html(&$vars) {
  global $theme_key, $user;

// Attributes for html element.
  $vars['html_attributes_array'] = array(
    'lang' => $vars['language']->language,
    'dir' => $vars['language']->dir,
  );

// Send X-UA-Compatible HTTP header to force IE to use the most recent rendering engine or use Chrome's frame rendering engine if available.
  if (is_null(drupal_get_http_header('X-UA-Compatible'))) {
    drupal_add_http_header('X-UA-Compatible', 'IE=edge,chrome=1');
  }

// Serialize RDF Namespaces into an RDFa 1.1 prefix attribute.
  if ($vars['rdf_namespaces']) {
    $prefixes = array();
    foreach (explode("\n  ", ltrim($vars['rdf_namespaces'])) as $namespace) {
      // Remove xlmns: and ending quote and fix prefix formatting.
      $prefixes[] = str_replace('="', ': ', substr($namespace, 6, -1));
    }
    $vars['rdf_namespaces'] = ' prefix="' . implode(' ', $prefixes) . '"';
  }

// Add to array of helpful body classes
  $vars['classes_array'][] = ($vars['is_admin']) ? 'admin' : 'not-admin';                                     // Page user is admin
  if (isset($vars['node'])) {
    $vars['classes_array'][] = ($vars['node']) ? 'full-node' : '';                                            // Full node
    $vars['classes_array'][] = (($vars['node']->type == 'forum') || (arg(0) == 'forum')) ? 'forum' : '';      // Forum page
  }
  else {
    $vars['classes_array'][] = (arg(0) == 'forum') ? 'forum' : '';                                            // Forum page
  }
  if (module_exists('panels') && function_exists('panels_get_current_page_display')) {                        // Panels page
    $vars['classes_array'][] = (panels_get_current_page_display()) ? 'panels' : '';
  }

// Add unique classes for each page and website section
  if (!$vars['is_front']) {
    $path = drupal_get_path_alias(check_plain($_GET['q']));
    list($section, ) = explode('/', $path, 2);
    $vars['classes_array'][] = ('section-' . $section);
    $vars['classes_array'][] = ('page-' . check_plain($path));
  }

// Build array of additional body classes and retrieve custom theme settings
$layoutwidth = theme_get_setting('layout-width');
  if ($layoutwidth == '0'){ 
    $vars['classes_array'][] = 'layout-jello';
  }
  if ($layoutwidth == '1'){ 
    $vars['classes_array'][] = 'layout-fluid';
  }
  if ($layoutwidth == '2'){ 
    $vars['classes_array'][] = 'layout-fixed';
  }
$sidebarslayout = theme_get_setting('sidebarslayout');
  if ($sidebarslayout == '0'){ 
	  $vars['classes_array'][] = 'var';
  }
  if ($sidebarslayout == '1'){ 
	  $vars['classes_array'][] = 'fix';
  }
  if ($sidebarslayout == '2'){ 
	  $vars['classes_array'][] = 'var1';
  }
  if ($sidebarslayout == '3'){ 
	  $vars['classes_array'][] = 'fix1';
  }
  if ($sidebarslayout == '4'){ 
	  $vars['classes_array'][] = 'eq';
  }
$bgimg = theme_get_setting('bgimg');
  if ($bgimg == '0'){ 
	  $vars['classes_array'][] = 'bi0';
  }
  if ($bgimg == '1'){ 
	  $vars['classes_array'][] = 'bi1';
  }
  if ($bgimg == '2'){ 
	  $vars['classes_array'][] = 'bi2';
  }
  if ($bgimg == '3'){ 
	  $vars['classes_array'][] = 'bi3';
  }
  if ($bgimg == '4'){ 
	  $vars['classes_array'][] = 'bi4';
  }
  if ($bgimg == '5'){ 
	  $vars['classes_array'][] = 'bi5';
  }
$bgpoz = theme_get_setting('bgpoz');
  if ($bgpoz == '0'){ 
	  $vars['classes_array'][] = 'bgs';
  }
  if ($bgpoz == '1'){ 
	  $vars['classes_array'][] = 'bgf';
  }
$sncol = theme_get_setting('sncol');
  if ($sncol == '0'){ 
	  $vars['classes_array'][] = 'sn0';
  }
  if ($sncol == '1'){ 
	  $vars['classes_array'][] = 'sn1';
  }
  if ($sncol == '2'){ 
	  $vars['classes_array'][] = 'sn2';
  }
  if ($sncol == '3'){ 
	  $vars['classes_array'][] = 'sn3';
  }
  if ($sncol == '4'){ 
	  $vars['classes_array'][] = 'sn4';
  }
  if ($sncol == '5'){ 
	  $vars['classes_array'][] = 'sn5';
  }
$ntcol = theme_get_setting('ntcol');
  if ($ntcol == '0'){ 
	  $vars['classes_array'][] = 'nt0';
  }
  if ($ntcol == '1'){ 
	  $vars['classes_array'][] = 'nt1';
  }
  if ($ntcol == '2'){ 
	  $vars['classes_array'][] = 'nt2';
  }
  if ($ntcol == '3'){ 
	  $vars['classes_array'][] = 'nt3';
  }
  if ($ntcol == '4'){ 
	  $vars['classes_array'][] = 'nt4';
  }
  if ($ntcol == '5'){ 
	  $vars['classes_array'][] = 'nt5';
  }
$fbcol = theme_get_setting('fbcol');
  if ($fbcol == '0'){ 
	  $vars['classes_array'][] = 'fb0';
  }
  if ($fbcol == '1'){ 
	  $vars['classes_array'][] = 'fb1';
  }
  if ($fbcol == '2'){ 
	  $vars['classes_array'][] = 'fb2';
  }
  if ($fbcol == '3'){ 
	  $vars['classes_array'][] = 'fb3';
  }
  if ($fbcol == '4'){ 
	  $vars['classes_array'][] = 'fb4';
  }
  if ($fbcol == '5'){ 
	  $vars['classes_array'][] = 'fb5';
  }
  if ($fbcol == '6'){ 
	  $vars['classes_array'][] = 'fb6';
  }
  if ($fbcol == '7'){ 
	  $vars['classes_array'][] = 'fb7';
  }
  if ($fbcol == '8'){ 
	  $vars['classes_array'][] = 'fb8';
  }
  if ($fbcol == '9'){ 
	  $vars['classes_array'][] = 'fb9';
  }
$mbcol = theme_get_setting('mbcol');
  if ($mbcol == '0'){ 
	  $vars['classes_array'][] = 'mb0';
  }
  if ($mbcol == '1'){ 
	  $vars['classes_array'][] = 'mb1';
  }
  if ($mbcol == '2'){ 
	  $vars['classes_array'][] = 'mb2';
  }
  if ($mbcol == '3'){ 
	  $vars['classes_array'][] = 'mb3';
  }
  if ($mbcol == '4'){ 
	  $vars['classes_array'][] = 'mb4';
  }
  if ($mbcol == '5'){ 
	  $vars['classes_array'][] = 'mb5';
  }
  if ($mbcol == '6'){ 
	  $vars['classes_array'][] = 'mb6';
  }
  if ($mbcol == '7'){ 
	  $vars['classes_array'][] = 'mb7';
  }
  if ($mbcol == '8'){ 
	  $vars['classes_array'][] = 'mb8';
  }
  if ($mbcol == '9'){ 
	  $vars['classes_array'][] = 'mb9';
  }
$lbcol = theme_get_setting('lbcol');
  if ($lbcol == '0'){ 
	  $vars['classes_array'][] = 'lb0';
  }
  if ($lbcol == '1'){ 
	  $vars['classes_array'][] = 'lb1';
  }
  if ($lbcol == '2'){ 
	  $vars['classes_array'][] = 'lb2';
  }
  if ($lbcol == '3'){ 
	  $vars['classes_array'][] = 'lb3';
  }
  if ($lbcol == '4'){ 
	  $vars['classes_array'][] = 'lb4';
  }
  if ($lbcol == '5'){ 
	  $vars['classes_array'][] = 'lb5';
  }
  if ($lbcol == '6'){ 
	  $vars['classes_array'][] = 'lb6';
  }
  if ($lbcol == '7'){ 
	  $vars['classes_array'][] = 'lb7';
  }
  if ($lbcol == '8'){ 
	  $vars['classes_array'][] = 'lb8';
  }
  if ($lbcol == '9'){ 
	  $vars['classes_array'][] = 'lb9';
  }
$mrcol = theme_get_setting('mrcol');
  if ($mrcol == '0'){ 
	  $vars['classes_array'][] = 'mr0';
  }
  if ($mrcol == '1'){ 
	  $vars['classes_array'][] = 'mr1';
  }
  if ($mrcol == '2'){ 
	  $vars['classes_array'][] = 'mr2';
  }
  if ($mrcol == '3'){ 
	  $vars['classes_array'][] = 'mr3';
  }
  if ($mrcol == '4'){ 
	  $vars['classes_array'][] = 'mr4';
  }
  if ($mrcol == '5'){ 
	  $vars['classes_array'][] = 'mr5';
  }
  if ($mrcol == '6'){ 
	  $vars['classes_array'][] = 'mr6';
  }
  if ($mrcol == '7'){ 
	  $vars['classes_array'][] = 'mr7';
  }
  if ($mrcol == '8'){ 
	  $vars['classes_array'][] = 'mr8';
  }
  if ($mrcol == '9'){ 
	  $vars['classes_array'][] = 'mr9';
  }
$trcol = theme_get_setting('trcol');
  if ($trcol == '0'){ 
	  $vars['classes_array'][] = 'tr0';
  }
  if ($trcol == '1'){ 
	  $vars['classes_array'][] = 'tr1';
  }
  if ($trcol == '2'){ 
	  $vars['classes_array'][] = 'tr2';
  }
  if ($trcol == '3'){ 
	  $vars['classes_array'][] = 'tr3';
  }
  if ($trcol == '4'){ 
	  $vars['classes_array'][] = 'tr4';
  }
  if ($trcol == '5'){ 
	  $vars['classes_array'][] = 'tr5';
  }
$btcol = theme_get_setting('btcol');
  if ($btcol == '0'){ 
	  $vars['classes_array'][] = 'bt0';
  }
  if ($btcol == '1'){ 
	  $vars['classes_array'][] = 'bt1';
  }
  if ($btcol == '2'){ 
	  $vars['classes_array'][] = 'bt2';
  }
  if ($btcol == '3'){ 
	  $vars['classes_array'][] = 'bt3';
  }
  if ($btcol == '4'){ 
	  $vars['classes_array'][] = 'bt4';
  }
  if ($btcol == '5'){ 
	  $vars['classes_array'][] = 'bt5';
  }
  if ($btcol == '6'){ 
	  $vars['classes_array'][] = 'bt6';
  }
$fntsize = theme_get_setting('fntsize');
  if ($fntsize == '0'){ 
	  $vars['classes_array'][] = 'fs0';
  }
  if ($fntsize == '1'){ 
	  $vars['classes_array'][] = 'fs1';
  }
  if ($fntsize == '2'){ 
	  $vars['classes_array'][] = 'fs2';
  }
$blockicons = theme_get_setting('blockicons');
  if ($blockicons == '1'){ 
    $vars['classes_array'][] = 'bicons';
  }
$pageicons = theme_get_setting('pageicons');
  if ($pageicons == '1'){ 
    $vars['classes_array'][] = 'picons';
  }

// Add language and site ID classes
  $vars['classes_array'][] = ($vars['language']->language) ? 'lg-'. $vars['language']->language : '';        // Page has lang-x
$siteid = check_plain(theme_get_setting('siteid'));
  $vars['classes_array'][] = $siteid;

  $vars['classes_array'] = array_filter($vars['classes_array']);                // Remove empty elements

// Add a unique page id
  $vars['body_id'] = 'pid-' . strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', drupal_get_path_alias(check_plain($_GET['q']))));

// Set IE6 & IE7 stylesheets
  drupal_add_css(drupal_get_path('theme','abc').'/css/ie6.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'lte IE 6', '!IE' => FALSE), 'preprocess' => FALSE));
  drupal_add_css(drupal_get_path('theme','abc').'/css/ie7.css', array('group' => CSS_THEME, 'browsers' => array('IE' => 'IE 7', '!IE' => FALSE), 'preprocess' => FALSE));
  drupal_add_css(drupal_get_path('theme','abc').'/css/style.css', array('group' => CSS_THEME, 'every_page' => TRUE));
  drupal_add_css(drupal_get_path('theme','abc').'/_custom/custom-style.css', array('group' => CSS_THEME, 'every_page' => TRUE));

$roundcorners = theme_get_setting('roundcorners');
  if ($roundcorners == '1'){ 
  drupal_add_css(drupal_get_path('theme','abc').'/css/round.css', array('group' => CSS_THEME, 'every_page' => TRUE));
}
  drupal_add_css(drupal_get_path('theme','abc').'/css/print.css', array('group' => CSS_THEME, 'media' => 'print', 'every_page' => TRUE));

  $vars['page_b'] = '<div class="by">by <a href="http://www.radut.net">Dr. Radut</a></div>';
}


/**
 * HTML processing
 */
function abc_process_html(&$vars, $hook) {
// Flatten out html_attributes.
  $vars['html_attributes'] = drupal_attributes($vars['html_attributes_array']);
}


/**
 * Page preprocessing
 */
function abc_preprocess_page(&$vars) {
// Hide breadcrumb on all pages
  if (theme_get_setting('breadcrumb_display') == 0) {
    $vars['breadcrumb'] = '';
  }

$logo = theme_get_setting('logo');
$defaultlogo = theme_get_setting('default_logo');
  if ($logo) {
    if ($defaultlogo){
      $vars['logo'] = base_path() . path_to_theme() . '/images/logo/' . theme_get_setting('logocol') . '/' . theme_get_setting('logoabc') . '.png';
    }
  }
}


/**
 * Breadcrumb override
 */
function abc_breadcrumb($vars) {
  $breadcrumb = $vars['breadcrumb'];
  if (!empty($breadcrumb)) {
// Provide a navigational heading to give context for breadcrumb links to screen-reader users. Make the heading invisible with .element-invisible.
    $breadcrumb[] = drupal_get_title();
    $output = '<h2 class="element-invisible">' . t('You are here') . '</h2>';
    $lastitem = sizeof($breadcrumb);
    $output .= '<ul class="breadcrumb">';
    $a=1;
    foreach($breadcrumb as $value) {
        if ($a!=$lastitem){
  $output .= '<li class="breadcrumb-'.$a.'">'. $value . t(' &raquo; ') . '</li>';
          $a++;
        }
        else {
            $output .= '<li class="breadcrumb-last">'.$value.'</li>';
        }
      }
     $output .= '</ul>';
    return $output;
  }
}


/**
 * Block preprocessing
 */
function abc_preprocess_block(&$vars) {
  global $theme_info, $user;
// Add regions with themed blocks to $themed_regions array and retrieve custom theme settings
$themedblocks = theme_get_setting('themedblocks');
  if ($themedblocks == '1'){ 
    $themed_regions = array('sidebar_first','sidebar_second');
  }
  if ($themedblocks == '2'){ 
    $themed_regions = array('user1','user2','user3','user4','user5','user6','user7','user8');
  }
  if ($themedblocks == '3'){ 
    $themed_regions = array('sidebar_first','sidebar_second','user1','user2','user3','user4','user5','user6','user7','user8');
  }
  if (isset($themed_regions) && is_array($themed_regions))
    $vars['themed_block'] = (in_array($vars['block']->region, $themed_regions)) ? TRUE : FALSE;
  else $vars['themed_block'] = FALSE;
}


/**
 * Node preprocessing
 */
function abc_preprocess_node(&$vars) {
// Build array of handy node classes
  $vars['classes_array'][] = $vars['zebra'];                                     // Node is odd or even
  $vars['classes_array'][] = (!$vars['node']->status) ? 'node-unpublished' : ''; // Node is unpublished
  $vars['classes_array'][] = ($vars['sticky']) ? 'sticky' : '';                  // Node is sticky
  $vars['classes_array'][] = ($vars['teaser']) ? 'teaser' : 'full-node';         // Node is teaser or full-node
  $vars['classes_array'][] = 'node-type-'. $vars['node']->type;                  // Node is type-x, e.g., node-type-page
// Change "Submitted by" display on all nodes, site-wide
$postedby = theme_get_setting('postedby');
  if ($postedby == '0'){ 
	  $vars['submitted'] = t('!datetime - !username', array('!username' => $vars['name'], '!datetime' => $vars['date']));
  }
  if ($postedby == '1'){ 
	  $vars['submitted'] = t('!username', array('!username' => $vars['name']));
  }
  if ($postedby == '2'){ 
	  $vars['submitted'] = t('!datetime', array('!datetime' => $vars['date']));
	  $vars['user_picture'] = '';
  }
}


/**
 * Comment preprocessing
 */
function abc_preprocess_comment(&$vars) {
  static $comment_odd = TRUE;                                                    // Comment is odd or even
  
// Build array of handy comment classes
  $vars['classes_array'][] = $comment_odd ? 'odd' : 'even';
  $comment_odd = !$comment_odd;
}


/**
 * Views preprocessing - Add view type class (e.g., node, teaser, list, table)
 */
function abc_preprocess_views_view(&$vars) {
  $vars['css_name'] = $vars['css_name'] .' view-style-'. drupal_clean_css_identifier(strtolower($vars['view']->plugin_name));
}


/**
 * Implements theme_field__field_type().
 */
function abc_field__taxonomy_term_reference($vars) {
  $output = '';

// Render the label, if it's not hidden.
  if (!$vars['label_hidden']) {
    $output .= '<div class="field-label">' . $vars['label'] . ': </div>';
  }

// Render the items.
  $output .= ($vars['element']['#label_display'] == 'inline') ? '<ul class="links inline">' : '<ul class="links">';
  foreach ($vars['items'] as $delta => $item) {
    $output .= '<li class="taxonomy-term-reference-' . $delta . '"' . $vars['item_attributes'][$delta] . '>' . drupal_render($item) . '</li>';
  }
  $output .= '</ul>';

// Render the top-level DIV.
  $output = '<div class="' . $vars['classes'] . (!in_array('clearfix', $vars['classes_array']) ? ' clearfix' : '') . '">' . $output . '</div>';

  return $output;
}


/**
 * Implements RDFa_preprocess_hook().
 */
function abc_preprocess_username(&$vars) {
// xml:lang alone is invalid in HTML5. Use the lang attribute instead.
  if (empty($vars['attributes_array']['lang'])) {
    $vars['attributes_array']['lang'] = '';
  }
  unset($vars['attributes_array']['xml:lang']);
  unset($vars['attributes_array']['property']);
  unset($vars['attributes_array']['rel']);
}


/**
 * Social links
 */
function abc_social_links() {
  $social = '';
  if (theme_get_setting('social_links_display')) {
    $displays_possible = array(
      'facebook' => 'social_links_display_links_facebook',
      'googleplus' => 'social_links_display_links_googleplus',
      'twitter' => 'social_links_display_links_twitter',
      'instagram' => 'social_links_display_links_instagram',
      'pinterest' => 'social_links_display_links_pinterest',
      'linkedin' => 'social_links_display_links_linkedin',
      'youtube' => 'social_links_display_links_youtube',
      'vimeo' => 'social_links_display_links_vimeo',
      'flickr' => 'social_links_display_links_flickr',
      'tumblr' => 'social_links_display_links_tumblr',
      'skype' => 'social_links_display_links_skype',
      'myother' => 'social_links_display_links_myother',
    );
    foreach ($displays_possible as $key => $display_possible) {
      $link_possible = $display_possible . '_link';
      if (theme_get_setting($display_possible) && $link = theme_get_setting($link_possible)) {
        $url = check_url($link);
        $nofollow = 'nofollow';
        $classes = 'sociallinks ' . $key;
        $social .= l('', $url, array('attributes' => array('rel' => $nofollow, 'class' => $classes)));
      }
    }
  }
  return $social;
}


/**
 * Other theme settings 
 */

function menupos() {
  $navpos = theme_get_setting('navpos'); // Primary & secondary links position 
    if ($navpos == '0'){ 
      return 'navleft';
  }
    if ($navpos == '1'){ 
      return 'navright';
  }
}

function abc_login(){
  global $user;
  $loginlinks = theme_get_setting('loginlinks');
  if ($loginlinks == '1'){ 
    if ($user->uid != 0) { 
      print '<ul class="links inline"><li class="first"><a href="' .url('user/'.$user->uid). '">' .$user->name. '</a></li><li><a href="' .url('user/logout'). '">' .t('Logout'). '</a></li></ul>'; 
    } 
    else { 
      print '<ul class="links inline"><li class="first"><a href="' .url('user'). '" rel="nofollow">' .t('Login'). '</a></li><li><a href="' .url('user/register'). '" rel="nofollow">' .t('Register'). '</a></li></ul>'; 
    }
  }
}

function divider() {
  $divider = theme_get_setting('themedblocks');
    if ($divider == '0' || $divider == '1') { 
      return 'divider';
  }
}
